@@ -444,7 +444,7 @@ def submitter_params(
     poll_interval=None,
     resource_monitor_interval=None,
     resource_monitor_type=None,
-    num_processes=None,
+    num_parallel_processes_per_node=None,
     verbose=None,
     reports=None,
     enable_singularity=None,
@@ -465,7 +465,7 @@ def submitter_params(
         poll_interval=poll_interval,
         resource_monitor_interval=resource_monitor_interval,
         resource_monitor_type=resource_monitor_type,
-        num_processes=num_processes,
+        num_parallel_processes_per_node=num_parallel_processes_per_node,
         verbose=verbose,
         reports=reports,
         enable_singularity=enable_singularity,
